import bpy
import bmesh

class MESH_OT_primitive_vert(bpy.types.Operator):
    """Create object with single vertex or add vertex to editmesh"""
    bl_idname = "mesh.primitive_vert"
    bl_label = "Create Vertex"
    bl_options = {'REGISTER', 'UNDO'}


    def execute(self, context):
        
        scene = context.scene
        ob = context.object

        if (ob is not None and
            ob.type == 'MESH' and
            ob.data.is_editmode):
            
            bpy.ops.mesh.select_all(action='DESELECT')
                    
            me = ob.data
            bm = bmesh.from_edit_mesh(me)
            co = scene.cursor_location - ob.matrix_world.translation
            v = bm.verts.new(co)
            v.select = True

            bmesh.update_edit_mesh(me, False, True)
            bpy.ops.mesh.select_mode(type='VERT')

        else:    

            bpy.ops.object.select_all(action='DESELECT')

            me = bpy.data.meshes.new("Vert")
            me.vertices.add(1)
            
            for ob in scene.objects:
                ob.select = False
                
            ob = bpy.data.objects.new("Vert", me)
            ob.location = scene.cursor_location
            ob.select = True
				
            scene.objects.link(ob)
            scene.objects.active = ob
            scene.update()
        
            bpy.ops.object.mode_set(mode='EDIT')
            bpy.ops.mesh.select_mode(type='VERT')
        
        
        return {'FINISHED'}
